#!/bin/sh
# $Id: rc.M,v 1.2 2001/01/09 03:22:51 zyrnix Exp $
#
# rc.M		This file is executed by init(8) when the system is being
#		initialized for one of the "multi user" run levels (i.e.
#		levels 1 through 6).  It usually does mounting of file
#		systems et al.
#
# Version:	@(#)/etc/rc.d/rc.M	2.02	02/26/93
#
# Author:	Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
#		Heavily modified by Patrick Volkerding <volkerdi@ftp.cdrom.com>
# 		Modified by Doug Hogan <zyrnix@users.sourceforge.net>
#

# Get the services to run
. /etc/rc.d/rc.conf
# Set the default binary locations
. /etc/rc.d/rc.paths

# Tell the viewers what's going to happen...
${ECHO} "Going multiuser..."

# Screen blanks after 15 minutes idle time.
if [ "X${screen_saver_enable}" = X"YES" -a -x ${SETTERM} ]; then
    ${SETTERM} ${screen_saver_args}
fi

# Look for a CD-ROM in a CD-ROM drive, and if one is found,
# mount it under /cdrom.  This must happen before any of the
# binaries on the CD are needed.
#
# If you don't have a CD-ROM and want to disable this, set the
# /etc/rc.d/rc.cdrom permissions to non-executable:
# chmod 644 /etc/rc.d/rc.cdrom
# 
if [ X"${rc_cdrom_enable}" = X"YES" -a -x /etc/rc.d/rc.cdrom ]; then
    . /etc/rc.d/rc.cdrom
fi

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# If there's no /etc/HOSTNAME, fall back on this default:
if [ ! -r /etc/HOSTNAME ]; then
    ${ECHO} "darkstar.example.net" > /etc/HOSTNAME
fi

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Set the hostname.  This might not work correctly if TCP/IP is not 
# compiled in the kernel.
${HOSTNAME} $(${CAT} /etc/HOSTNAME | ${CUT} -f1 -d .)

# Initialize the NET subsystem.
if [ X"${rc_network_enable}" = X"YES" -a -x /etc/rc.d/rc.inet1 ]; then
    . /etc/rc.d/rc.inet1
    . /etc/rc.d/rc.inet2
else
    if [ X"${syslogd_enable}" = X"YES" -a -x ${SYSLOGD} ]; then
        ${SYSLOGD} ${syslogd_args}
        ${SLEEP} 1 # Prevents a race condition with SMP kernels
    fi
    if [ X"${klogd_enable}" = X"YES" -a -x ${KLOGD} ]; then
        # '-c 3' displays level 'error' or higher messages on the console
        ${KLOGD} ${klogd_args}
    fi
    if [ X"${lpd_enable}" = X"YES" -a -x ${LPD} ]; then
        ${LPD} ${lpd_args}
    fi
fi

# Start netatalk. (a file/print server for Macs using Appletalk)
if [ X"${rc_atalk_enable}" = X"YES" -a -x /etc/rc.d/rc.atalk ]; then
    . /etc/rc.d/rc.atalk
fi

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/adm/cron, then change
# -l10 to -l8 to increase the logging level.
${CROND} -l10 >>/var/adm/cron 2>&1

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Start atd (manages jobs scheduled with 'at'):
${ATD} -b 15 -l 1

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Remove stale locks and junk files (must be done after mount -a!)
${RM} -f /var/lock/* /var/spool/uucp/LCK..* /tmp/.X*lock /tmp/core /core 1> /dev/null 2> /dev/null

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Remove stale hunt sockets so the game can start.
if [ -r /tmp/hunt -o -r /tmp/hunt.stats ]; then
    ${ECHO} "Removing your stale hunt sockets from /tmp..."
    ${RM} -f /tmp/hunt*
fi

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Ensure basic filesystem permissions sanity.
${CHMOD} 755 /
${CHMOD} 1777 /tmp /var/tmp

# There's no option in /etc/rc.d/rc.conf for this since it is needed.
# Update all the shared library links automatically
${LDCONFIG}

# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' to the appropriate
# partitions as listed in /etc/fstab.  Here's an example:
# /dev/hda2   /home   ext2   defaults,usrquota    1   1
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
# touch /home/quota.user /home/quota.group
# chmod 600 /home/quota.user /home/quota.group
# Then, reboot to activate the system.
# To edit user quotas, use 'edquota'.  See 'man edquota'.  Also, the
# official Quota Mini-HOWTO has lots of useful information.  That can be found
# here:  ftp://ftp.cdrom.com/pub/linux/slackware/docs/mini/Quota
#
# Check quotas and then turn quota system on:
if [ X"${quotas_enable}" = X"YES" ]; then
    if [ ${FGREP} quota /etc/fstab 1> /dev/null 2> /dev/null ; then
        if [ -x ${QUOTACHECK} ]; then
            ${ECHO} "Checking filesystem quotas..."
            ${QUOTACHECK} ${quotas_enable_args}
        fi
        if [ -x ${QUOTAON} ]; then
            ${ECHO} "Activating filesystem quotas..."
            ${QUOTAON} ${quotas_enable_args}
        fi
    fi
fi

# Start the sendmail daemon:
if [ X"${sendmail_enable}" = X"YES" -a -x ${SENDMAIL} ]; then
    ${ECHO} "Starting sendmail (${SENDMAIL} ${sendmail_args})..."
    ${SENDMAIL} ${sendmail_args}
fi

# Start the APM daemon if APM is enabled in the kernel:
if [ X"${apmd_enable}" = X"YES" -a -x ${APMD} ]; then
    if [ ${CAT} /proc/apm 1> /dev/null 2> /dev/null ; then
        ${ECHO} "Starting ${APMD} daemon..."
        ${APMD} ${apmd_args}
    fi
fi

# Load a custom screen font if the user has an rc.font script.
if [ X"${rc_font_enable}" = X"YES" -a -x /etc/rc.d/rc.font ]; then
    . /etc/rc.d/rc.font
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ X"${rc_keymap_enable}" = X"YES" -a -x /etc/rc.d/rc.keymap ]; then
    . /etc/rc.d/rc.keymap
fi

# iBCS Emulation for Linux
# The Intel Binary Compatibility Specification, or iBCS, specifies the
# interfaces between application programs and the surrounding operating
# system environment for i386 based systems. There are however several
# flavours of iBCS in use - SVR4, SVR3 plus several vendor specific
# extensions to SVR3 which are slightly different and incompatible. The
# iBCS emulator for Linux supports all flavours known so far.
if [ X"${rc_ibcs2_enable}" = X"YES" -a -x /etc/rc.d/rc.ibcs2 ]; then
    . /etc/rc.d/rc.ibcs2
fi

# Start Web server:
if [ X"${rc_httpd_enable}" = X"YES" -a -x /etc/rc.d/rc.httpd ]; then
    . /etc/rc.d/rc.httpd
fi 

# Start Samba (a file/print server for Win95/NT machines):
if [ X"${rc_samba_enable}" = X"YES" -a -x /etc/rc.d/rc.samba ]; then
    . /etc/rc.d/rc.samba
fi

# Start the GPM mouse server:
if [ X"${rc_gpm_enable}" = X"YES" -a -x /etc/rc.d/rc.gpm ]; then
    . /etc/rc.d/rc.gpm
fi

# If there are SystemV init scripts for this runlevel, run them.
if [ X"${rc_sysvinit_enable}" = X"YES" -a -x /etc/rc.d/rc.sysvinit ]; then
    . /etc/rc.d/rc.sysvinit
fi

# Start the local setup procedure.
if [ X"${rc_local_enable}" = X"YES" -a -x /etc/rc.d/rc.local ]; then
    . /etc/rc.d/rc.local
fi

