#!/bin/sh
# $Id: install.sh,v 1.21 2001/03/28 07:30:26 zyrnix Exp $

#############################################
#
# SAStk install Script
#
# For Slackware Linux 7.0 - 7.1
#
#############################################
# SAStk 0.1
# Copyright (C) 2000 John Jenkins, Doug Hogan, Jeffrey Denton
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###########################

# Sanity check
if [ ! -d /etc/rc.d ]; then
    mkdir -p /etc/rc.d
fi

# Set default binary locations
# The path should be relative so the install script goes as planned.
. etc/rc.d/rc.paths 

###############
#Check for root
###############

ver="0.1.2.0"

${CLEAR}

if [ ! "${UID}" = "0" ]; then
    ${ECHO} -e "  You must be root to run the SAStk script!! \a"
    ${ECHO} "  Please log in or \"su -\" to root."
    exit
fi

${CAT} << EOF
********************************************************************************
*             Welcome to the SAStk installation script version ${ver}
********************************************************************************

Checking System.

Please wait
EOF

#################
# Check version #
#################

if [ ! -f "/etc/slackware-version" ]; then
    ${ECHO} -e "\n/etc/slackware-version does NOT exist!!\n"
    ${ECHO} -e "\nAre you sure this is Slackware?\n"
    exit
fi

version=$(${CAT} /etc/slackware-version)

if [ "${version}" = "7.0.0" -o "${version}" = "7.1.0" ]; then
    ${CAT} << EOF

Checking Version.
EOF
else
${CLEAR}
    ${CAT} << EOF
********************************************************************************
*                     SAStk installation script version ${ver}
********************************************************************************

SAStk does not support Slackware ${version} at this time.
Bug the developers until they include support for it.
EOF
    exit
fi

##########################################
# Check if SAStk is installed already 
##########################################

if [ -f /etc/rc.d/rc.conf ]; then
    ${ECHO} "SAStk is already installed!!"
    ${ECHO} "please run ./sastk.sh to configure your system"
    ${ECHO} "or ./sastk_undo.sh to uninstall SAStk"
    exit
fi 

##########################################
# Check if SAStk has been installed before
##########################################

if [ "${1}" != "-force" ];then
    if [ -d /var/log/sastk ]; then
        ${ECHO} "We detect that you still have the logs and backup files"
        ${ECHO} "from a previous SAStk installation" 
        ${ECHO} "If you have uninstalled SAStk you can rm -rf /var/log/sastk"
        ${ECHO} "to remove the previous installs backup and log files"
        ${ECHO} "or you may wish to rename the /var/log/sastk directory"
        ${ECHO} "If you wish to append the logs from this install to"
        ${ECHO} "the existing logs then you may run $0 -force"
        ${ECHO} "to overide this check"
        exit
    fi
fi

###############################
# Checking for single user mode
###############################

if [ "$(${RUNLEVEL} | ${AWK} '{print $2}')" != "1" ]; then
    ${ECHO} ""
    ${CLEAR}
    quit=n
    ${CAT} << EOF
********************************************************************************
*                     SAStk installation script version ${ver}
********************************************************************************


This script should be run in single user mode
If you are in single user mode then we screwed up ... press < 1 > to continue
If you are not already in single user mode press < 2 > to enter this mode

EOF
    while [ "${quit}" = "n" ]; do
        ${CAT} << EOF

Choose an option from the list

1) I know what I'm doing Continue in current mode
2) Enter Single user mode
Q) Quit this script

EOF

      ${ECHO} -ne "Choose an option: .\b"
      read choice
      case ${choice} in

          1)       quit="y"; ${CLEAR}
                   ;;
          2)     if [ -f /root/.bash_login ]; then
                      ${CP} /root/.bash_login /root/.bash_login.bak
                 fi
                 CDIR=$(${PWD})
                 ${CAT} > /root/.bash_login <<EOF
#!/bin/sh
echo
if [ "\$(/sbin/runlevel | awk '{print \$2}')" = "1" ]; then
clear
echo
quit="n"
    while [ "\${quit}" = "n" ]; do
cat << !
********************************************************************************
*                     SAStk installation script version ${ver}
********************************************************************************

This is part of the SAStk Installation
You should now be in Single user mode.
please choose an option from below.


1) Every thing seems okay.. continue with the installation
2) What the.... Stop this madness and don't let it happen again
Q) Just quit this I'll handle the rest myself

!
    echo -ne "Choose an Option: .\b"
    read choice
    case \${choice} in
        1)       quit="y"
                 cd ${CDIR}
                 ./install.sh
                   ;;
        2)       if [ -f /root/.bash_login.bak ]; then
                     mv /root/.bash_login.bak /root/.bash_login
                 elif [ -f /root/.bash_login ]; then
                     rm /root/.bash_login
                 fi
                 quit="y"
                 clear
                   ;;
      Q|q)       quit="y"
                 clear
                   ;;
        *)       echo -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi
EOF
                 ${ECHO} "Switching to S Mode.  You will need to log back in as root."
                 ${ECHO} "The install should continue automatically"
                   ${TELINIT} 1; exit 0
                   ;;
        Q|q)       ${CLEAR}; exit 1
                   ;;
          *)       ${ECHO} -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi

OLDPATH="${PATH}"
PATH=/sbin:/usr/sbin:/bin:/usr/bin
umask 077

##############################
# Define and export logfiles #
##############################

export LOG="/var/log/sastk"
export TMPDIR="/root/sastk_tmp"
export logfile="${LOG}/sastk_install.log"
export errlog="${LOG}/sastk_err.log"
export BKUP="${LOG}/backup"

[ ! -d "${LOG}" ] && ${MKDIR} "${LOG}"
[ ! -d "${TMPDIR}" ] && ${MKDIR} "${TMPDIR}"
[ ! -d "${BKUP}" ] && ${MKDIR} "${BKUP}"
[ ! -f "${logfile}" ] && ${TOUCH} "${logfile}"
[ ! -f "${errlog}" ] &&  ${TOUCH} "${errlog}"

${ECHO} ""
${ECHO} "Setting up logging"
${ECHO} "Install log is ${logfile}"
${ECHO} "Backups are under ${BKUP}"
${ECHO} "" 

#####################
# Set some defaults #
#####################

export RC="/etc/rc.d"

###########################
# Create backup directories
###########################

for dir in \
/etc \
/etc/rc.d \
/root \
/var \
/var/X11R6 \
/var/X11R6/lib \
/var/X11R6/lib/xdm \
/usr \
/sbin \
/usr/X11R6 \
/usr/X11R6/bin ;do
     [ ! -d ${BKUP}${dir} ] && ${MKDIR} "${BKUP}${dir}"
done

# Set sendmail directory
if [ "${version}" = "7.0.0" ]; then
    SENDMAILDIR="/etc"
elif [ "${version}" = "7.1.0" ]; then
    SENDMAILDIR="/etc/mail"
else
    ${ECHO} -e "\nHow did you get this far?\n"
    exit
fi

export SENDMAILDIR
[ ! -d "${BKUP}${SENDMAILDIR}" ] && ${MKDIR} "${BKUP}${SENDMAILDIR}"

CURRENT_DATE=$(date)
SASTK_ID='$Id: install.sh,v 1.21 2001/03/28 07:30:26 zyrnix Exp $'

##################
# Start the work #
##################

${ECHO} "SAStk was installed on $CURRENT_DATE." >> ${logfile}
${ECHO} ${SASTK_ID} >> ${logfile}
${ECHO} ""
${ECHO} "System checks out okay"
${ECHO} -ne "\npress enter to begin installing the files.\n> "
read junk

# Back up and install sasrc
# Don't backup and install CVS tree maintenance files.
for i in $(${FIND} etc/ -type f | ${GREP} -v CVS); do
    file=${i}
    newfile="/${i}"
    ${CP} -p "${newfile}" "${BKUP}${newfile}" 1>> ${logfile} 2>> ${errlog}
    ${CP} -vpf "${file}" "${newfile}"  1>> ${logfile} 2>> ${errlog}
done

# Backup and install netconfig.color
if [ ! -f "${BKUP}/sbin/netconfig.color" ]; then
    ${CP} -pf "/sbin/netconfig.color" "${BKUP}/sbin/netconfig.color" 2>> ${errlog}
fi
${CP} -pf "sbin/netconfig.color" "/sbin/netconfig.color" 2>> ${errlog}

# Create /etc/rc.d/rc.0 symlink to /etc/rc.d/rc.6
if [ ! -L /etc/rc.d/rc.0 ]; then
    ${LN} -s /etc/rc.d/rc.6 /etc/rc.d/rc.0
fi

# Set permissions for rc.d and netconfig.color
${CHMOD} 0700 /etc/rc.d/rc.* "/sbin/netconfig.color" 2>> ${errlog}
${CHOWN} root.root /etc/rc.d/rc.* "/sbin/netconfig.color" 2>> ${errlog}

# Make backups of all files to be modified.
for x in $(${CAT} filelist);do
    if [ -f ${x} ]; then
        if [ ! -f "${BKUP}${x}" ]; then
        ${CP} -vp "${x}" "${BKUP}${x}" 1>> ${logfile} 2>> ${errlog}
        fi
        ${CP} -p "${x}" "${BKUP}${x}.sastk" 2>> ${errlog}
    fi
done

# Create md5sums for files that will be modified
for m in $(${CAT} filelist);do
    if [ -f ${m} ]; then
        ${MD5SUM} "${m}" 1>> "${LOG}/filelist.md5" 2>> ${errlog}
    fi
done

# Install sastk.info file
if [ ! -f /usr/local/info/sastk.info ]; then
    ${CP} "../docs/sastk.info" "/usr/local/info/" 2>> ${errlog}
fi
    ${INSTALLINFO} "../docs/sastk.info" "/usr/local/info/dir" 2>> ${errlog}

# Finishing up
${ECHO} "Slackware Administrator's Security Toolkit installation" 
${ECHO} "has completed successfully"
${ECHO} "Installation of $SASTK_ID completed on $CURRENT_DATE" >> ${logfile}

# Take care of .bash_login
if [ -f /root/.bash_login.bak ]; then
    ${MV} /root/.bash_login.bak /root/.bash_login
elif [ -f /root/.bash_login ]; then
    ${RM} /root/.bash_login 2>> ${errlog}
fi

# unset anything we've exported
for i in errlog logfile BKUP LOG RC SENDMAILDIR TMPDIR version ; do
    unset $i
done

export PATH="${OLDPATH}"

${ECHO} ""
${ECHO} -ne "\npress enter to begin the configuration\n> "
read junk
./sastk.sh
#exit 0 # Should Return to index script here

#################
# End of script #
#################
