#!/bin/sh
# $Id: sastk.sh,v 1.25 2001/04/15 08:01:02 zyrnix Exp $

#############################################
#
# SAStk Hardening Script
#
# For Slackware Linux 7.0 - 7.1
#
#############################################
# SAStk 0.1
# Copyright (C) 2000 John Jenkins, Doug Hogan, Jeffrey Denton
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###########################

# Set default binary locations
. /etc/rc.d/rc.paths

###############
#Check for root
###############

ver="0.1.2.0"

${CLEAR}

if [ ! "${UID}" = "0" ]; then
    ${ECHO} -e "  You must be root to run the SAStk script!! \a"
    ${ECHO} "  Please log in or \"su -\" to root."
    exit
fi

${CAT} << EOF
********************************************************************************
*             Welcome to the SAStk hardening script version ${ver}
********************************************************************************

Checking System

Please wait
EOF

#################
# Check version #
#################

if [ ! -f "/etc/slackware-version" ]; then
    ${ECHO} -e "\n/etc/slackware-version does NOT exist!!\n"
    ${ECHO} -e "\nAre you sure this is Slackware?\n"
    exit 
fi     

version=$(${CAT} /etc/slackware-version)

if [ "${version}" = "7.0.0" -o "${version}" = "7.1.0" ]; then
    ${ECHO} ""
else
    ${CAT} << EOF

SAStk does not support Slackware ${version} at this time.
Bug the developers until they include support for it.
EOF
    exit
fi     

##############################
#Checking for single user mode
##############################

if [ "$(${RUNLEVEL} | ${AWK} '{print $2}')" != "1" ]; then
    ${ECHO} ""
    ${CLEAR} 
    quit=n
    ${CAT} << EOF

This script should be run in single user mode
If you are in single user mode then we screwed up ... press < 1 > to continue
If you are not already in single user mode press < 2 > to enter this mode

EOF
    while [ "${quit}" = "n" ]; do
        ${CAT} << EOF

Choose an option from the list

1) I know what I'm doing Continue in current mode
2) Enter Single user mode
Q) Quit this script

EOF

      ${ECHO} -ne "Choose an option: .\b"
      read choice
      case ${choice} in

  	  1)       quit="y"; ${CLEAR}
                   ;;
          2)     [ -f /root/.bash_login ] && ${CP} "/root/.bash_login" "/root/.bash_login.bak"
                 CDIR=$(${PWD})
                  ${CAT} > /root/.bash_login <<EOF
#!/bin/sh
echo
if [ "\$(/sbin/runlevel | awk '{print \$2}')" = "1" ]; then
echo
quit="n"
    while [ "\${quit}" = "n" ]; do
cat << !

This is part of the SAStk configuration
You should now be in Single user mode.
please choose an option from below.

1) Every thing seems okay.. continue with the configuration
2) What the.... Stop this madness and don't let it happen again
Q) Just quit this I'll handle the rest myself

!
    echo -ne "Choose an Option: .\b"
    read choice
    case \${choice} in
        1)       quit="y"
                 cd ${CDIR}
                 ./sastk.sh
                   ;;
        2)       if [ -f /root/.bash_login.bak ]; then
                     mv /root/.bash_login.bak /root/.bash_login
                 elif [ -f /root/.bash_login ]; then
                     rm /root/.bash_login
                 fi
                 quit="y"
                 clear
                   ;;
      Q|q)       quit="y"
                 clear
                   ;;
        *)       echo -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi
EOF
	           ${ECHO} "Switching to S Mode.  You will need to log back in as root."
                   ${ECHO} "This script should continue automatically"
                   ${TELINIT} 1; exit 0
                   ;;
        Q|q)       ${CLEAR}; exit 1
                   ;;
          *)       ${ECHO} -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi

OLDPATH="${PATH}"
PATH=/sbin:/usr/sbin:/bin:/usr/bin
umask 077


##############################
# Define and export logfiles #
##############################

export LOG="/var/log/sastk"
export TMPDIR="/root/sastk_tmp"
export logfile="${LOG}/sastk.log"
export errlog="${LOG}/sastk_err.log"
export BKUP="${LOG}/backup"

[ ! -d "${LOG}" ] && ${MKDIR} "${LOG}"
[ ! -d "${TMPDIR}" ] && ${MKDIR} "${TMPDIR}"
[ ! -d "${BKUP}" ] && ${MKDIR} "${BKUP}"  
[ ! -f "${logfile}" ] && ${TOUCH} "${logfile}"
[ ! -f "${errlog}" ] &&  ${TOUCH} "${errlog}"

#####################
# Set some defaults #
#####################

export RC="/etc/rc.d"

[ ! -d "${BKUP}/etc" ] && ${MKDIR} "${BKUP}/etc"
[ ! -d "${BKUP}${RC}" ] && ${MKDIR} "${BKUP}${RC}"
 
# Set sendmail directory
if [ "${version}" = "7.0.0" ];then
    SENDMAILDIR="/etc"
elif [ "${version}" = "7.1.0" ];then
    SENDMAILDIR="/etc/mail"
else
    ${ECHO} -e "\nHow did you get this far?\n"
    exit 
fi

export SENDMAILDIR
[ ! -d "${BKUP}${SENDMAILDIR}" ] && ${MKDIR} "${BKUP}${SENDMAILDIR}"

CURRENT_DATE=$(date)
SASTK_ID='$Id: sastk.sh,v 1.25 2001/04/15 08:01:02 zyrnix Exp $'

#############
# Functions #
#############

# This function should be run anytime a change is made to a non SASrc file
# It will make a current BKUP/filename.sastk and update the LOG/filelist.md5
update_md5() {
   # Update the backup.sastk
   ${CP} -pf "${1}" "${BKUP}${1}.sastk"
   # Update md5sum 
   md5name=$(${BASENAME} ${1})
   ${SED} "/${md5name}/d" "${LOG}/filelist.md5" > "${TMP}/filelist.md5"
   ${MD5SUM} "${1}" >> "${TMP}/filelist.md5"
   ${MV} "${TMP}/filelist.md5" "${LOG}/filelist.md5"
}

# This function will be run when a user answers YES to make a change to 
# a non SASrc file.
# It will compare the current md5sum with the one in LOG/filelist.md5 and warn
# the user that the file has been altered by something other than SAStk
# We will then tell the user that we are reverting to our copy of the file
# and create a backup and a unified diff with instructions on applying the 
# patch or hand editing the file
check_md5() {
if [ -n "$(${MD5SUM} -c ${LOG}/filelist.md5 2>/dev/null |${GREP} -s FAILED |${GREP} -s ${1})" ]; then
    ${CAT} << EOF
               * * * * * * * ATTENTION * * * * * * *
      We have detected a change in ${1} that was not made by SAStk

 To ensure this does not affect our changes we will revert to our 
 last copy of ${1} and backup the modified copy to ${1}.bkup 
    We will also create a patch file called ${1}.patch 
 ${0} will then continue on leaving you with the following choices:

1/ Edit the new copy of ${1} by hand to reinstate your changes

2/ Try running the patch against the new copy of ${1}
   this may not work so you should test this out on a copy first

3/ Hand edit and add the changes from the new ${1} to the .bkup
   and then mv ${1}.bkup ${1}

 Do note that editing the files after the completion of ${0} 
will cause this message to appear the next time $0 is run.

                Please hit ENTER to continue

EOF

    read junk

    ${CLEAR}
    ${DIFF} -u "${BKUP}${1}.sastk" "${1}" > "${1}.patch"
    ${CP} -vpf "${1}" "${1}.bkup" 1>> ${logfile} 2>> ${errlog}
    ${CP} -vpf "${BKUP}${1}.sastk" "${1}" 1>> ${logfile} 2>> ${errlog}
fi
}

# This function will require the user to answer 'YES' or 'NO' and is used for
# all non-SASrc variables.
check_answer() {
   # Make sure the next question is properly answered by the user and the value
   # is not reused from the previous question.
   some_answer="???"
   ${ECHO} -n "answer: "
   read some_answer
   # Use tr to make the answer all uppercase
   some_answer="$(${ECHO} ${some_answer} | ${TR} "a-z" "A-Z" )"
   until [ "${some_answer}" = "NO" -o "${some_answer}" = "YES" ]; do
      ${ECHO} "You have entered an incorrect response.  Please choose YES or NO."
      ${ECHO} "$*"
      ${ECHO} -n "answer: "
      read some_answer
      some_answer="$(${ECHO} ${some_answer} | ${TR} "a-z" "A-Z")"
  done 
}

# This replaces the questions section previously.
display_info_daemon() {
    DAEMON=$1
    case ${DAEMON} in 

        begin)				${MORE} << EOF


                   Selecting Services to run.


You'll notice that many of these services we recommend you DISABLE.  Yes,
they are running on default installs, but that's why this project was started.
There are silly things running that most users won't need, and if they knew
what they were for, would not choose to run.

Enable the essentials.  If you need something, learn about it first, then 
enable it.  We will try to give you an overview on what the services do
and if they are particularly harmful, but many of the details on the security
are left up to you.  We provide you with general responses on what is good
or bad, but your circumstances may need additional work.


Pressing 'enter' on any of these options will NOT make a change in that option
and will move onto the next option.  The status line at the top always tells you
what your last answer was.

Press 'enter' to continue on choosing the daemons (servers) you wish to enable.
EOF
;;

        mounting_nfs_enable)           ${MORE} << EOF
Mounting NFS (Network File Systems).

This will mount all of your file systems listed in /etc/fstab as type NFS.
The mounting of the file systems is a client side operation.  This is not
a server on your machine, but a remote server that must be running nfsd with
permissions set to allow you to mount the file system.

This is unencrypted and the authentication is usually weak.  Use if you trust
the network and the host and you need this.

Would you like to enable mounting remote NFS drives? (YES or NO).






EOF
;;

	isa_pnp_enable)			${MORE} << EOF
ISA PNP (Plug and Play) support.

If you enable this option, the system will try to configure your ISA plug and
play devices using /sbin/isapnp.  The default file is /etc/isapnp.conf where
the information on your ISA devices is stored.

Would you like to enable ISA plug and play support for your devices? (YES or NO)










EOF
;;

	session_manager_enable)		${MORE} << EOF
Session Manager.

A session manager (or commonly called display manager) is used when your system
boots to a certain runlevel.  In slackware, this runlevel is 4.  In other
systems it is runlevel 5 and some call it directly.  In any case, the session
manager will boot up the X Window System with a GUI prompt for a user login.
You will not have the default command line login, but instead one of the
three available logins.

For the other option, choose which login you would like to use:
XDM - the XFree86 default display manager
GDM - GNOME's display manager
KDM - KDE's display manager

You should read /etc/inittab or the init command to enable it.

Please select YES to have a session manager when in runlevel 4, or NO
EOF
;;

	hwclock_enable)		${MORE} << EOF
Hardware Clock adjustment.

If you would like your Slackware machine to save the local time that your
computer reports currently to the hardware clock, then select YES here.

If in doubt, you should choose NO here.

Please select either YES or NO.









EOF
;;
	
	screen_saver_enable)	${MORE} << EOF
Screen Saver enable.

If you would like to enable a screen saver for your Slackware machine, select
YES here.  If not, select NO.  Either option is safe, it's a matter of 
personal preference.

The default is to have a blank screen after 15 minutes.  You can change this
in the /etc/rc.d/rc.conf file under the option "screen_saver_args="

Please select either YES or NO.







EOF
;;

	ipv4_forward_enable)	${MORE} << EOF
IP version 4 Forwarding enable.

If you plan on running a gateway or router machine then select YES to this
option.  It allows for packets to be forwarded between interfaces at the
network layer level.  If you wish to run a firewall, you must enable this
also.  It is commonly used in IP Masquerading.

This can be considered dangerous if you do not have a machine properly 
configured.  If you do not know what a gateway or router is, please choose
NO here.  The only side effect of not enabling this is that you will not
be able to run a gateway or router.  The disadvantage is that if you enable
it, you must know what you are doing because it can be exploited.

Please select YES if you feel you understand how gateways and routers work,
NO if you just want a work station and do not want another potential problem.


EOF
;;

	rp_filter_enable)	${MORE} << EOF
RP Filter enable

When using IPv4 packet forwarding, you will also get the rp_filter, which
automatically rejects incoming packets if the routing table entry for their
source address doesn't match the network interface they're arriving on.  This
has security advantages because it prevents the so-called IP spoofing,
however it can pose problems if you use asymmetric routing (packets from you
to a host take a different path than packets from that host to you) or if
you operate a non-routing host which has several IP addresses on different
interfaces.

Please select YES to enable, NO to disable.





EOF
;;

	syslogd_enable)		${MORE} << EOF
Syslogd (System logging daemon).

This is Linux's system logger.  It is generally safe, but there have been 
exploits in the past.  

This is not strictly needed.

Select YES to enable, or NO to disable.









EOF
;;

	klogd_enable)		${MORE} << EOF
Klogd (Kernel logging daemon).

This is the kernel logger which helps to debug problems relating to the kernel
as it intercepts/records kernel activity.

This is also not strictly needed.

Select YES to enable, or NO to disable.









EOF
;;

	inetd_enable)		${MORE} << EOF
Inet Super Server.

Inetd is a service which spawns child processes when a connection is made.
There are many, many services enabled by default in /etc/inetd.conf in a
default slackware install.

You should carefully look through the file /etc/inetd.conf before you say
YES to this question.  There are a lot of services that you probably
don't want running or should have updated versions.

Select YES if you have read through /etc/inetd.conf and understand what
each option does.  If you do not, select NO, and we'll handle configuring
the daemons later on.   After that point, you can enable inetd.




EOF
;;

	sshd_enable)		${MORE} << EOF
sshd (Secure Shell daemon).

Secure shell is a replacement for the inherently insecure telnet, rcp
(remote copy) and other BSD r* services.  Secure shell uses strong encryption
to encrypt the session and can be used in conjunction with Kerberos and
S/Key.  Scp (secure copy) and other services such as s-ftp (secure file
transfer protocol) are also included in the OpenSSH suite.

ssh does not protect against weak passwords.  Make sure you always use
good passwords (no dictionary words, at least 8 chars in length, vary case).

OpenSSH is a free replacement for version 1.5 and 2.0 ssh protocol.  The 
commercial ssh is not free software.

Select YES if you want to be able to remotely login to your machine.  Select
NO if you will not remotely login or use weak passwords.

EOF
;;

	bind_enable)		${MORE} << EOF
BIND (Berkeley Internet Daemon) and Named (Internet Domain Name Server).

BIND/Named is used for DNS requests.  If you want to maintain your own DNS
server then select YES.  You can just as easily use your ISP's DNS server.

Be aware that BIND has been a security problem in the past and could lead
to root exploits.  Also, you do not always have a speed advantage over an 
ISP's DNS server since you have to make connections over your connection.

Later on you can select between BIND running as root versus user.  The
advantage to running as root is that you can use the "well-known" ports
which are reserved for root usage (IANA defined ports 1-1023).  The advantage
of running as a user is that if your server is exploited, then the damage will
be done as a limited access user rather than full access root.

Select YES if you understand BIND and how to secure it and want to host a
server, most should select NO as it is not needed or wanted.
EOF
;; 	

	routed_enable)		${MORE} << EOF
Routed - routing server.

This is most useful in large networks where you have complicated routing
tables that need to be updated by a centralized location.  You can use
this to dynmically update the kernel routing table.

Only run routed if you are familiar with the configuration, and most users
will not want to run this.

This is not in general needed.

Select YES if you know routed and need it, most users should select NO
as it is not needed.




EOF
;;

	rwhod_enable)		${MORE} << EOF
Rwhod - remote who daemon.

Most users won't want to enable this.  All it does is allow other people 
to tell information about you and you can retrieve info on others running
rwho also.  It's not very beneficial unless you are in a secured DMZ
(demilitarized zone, basically if you are on a secured segment).

Select YES if you like running silly daemons for no good reason, select NO
if you're smart.








EOF
;;

	various_inetd_enable)	${MORE} << EOF
Various Internet Daemons.

Hard for us to even categorize this.  It really depends on your setup.  You
do not explicitly need any of these services.

If you do plan on running any of them, make sure you know which daemons are
being called.  Most users won't need or want this option.

Select YES if you want to chance it on what services will run, most users 
should select NO.







EOF
;;

	nis_domainname_enable)	${MORE} << EOF
NIS Domain Name.

If you are in an NIS environment, we all feel sorry for you :).  If you 
need this service, make sure you review the configuration and think about
redesigning your network to get rid of NIS/YP.

Most users won't want to touch this option with good reason.

Select YES if you are in an NIS environment and must have this, most users
should select NO as you have no need for this.







EOF
;;

	rpc_nfsd_enable)		${MORE} << EOF
NFS daemon (Network File System).

NFS, the somewhat popular, easily misunderstood daemon.  nfsd will allow other
machines to connect and mount the mount points you have listed in /etc/exports.

Experienced users will groan at the sight of one of these silly RPC daemons.
Use it only if you have to.  It causes many more headaches than it's worth.
If you need to mount file systems remotely like this, look into AFS which is
an encrypted replacement for nfsd.

Use this with extreme care, you can easily expose your entire hard drive
to the world with this daemon running.  And all traffic is unencrypted between
the two machines.

Select YES if you want to enable this.  Most users will NOT want to enable this
so select NO.

EOF
;;

	nis_ypbind_enable)		${MORE} << EOF
YP Bind daemon.

YPbind is used with NIS to retreive information and store it in a file.

If you have the unfortunate luck of needing it, only enable it after you
have reviewed the configuration files.

Most users won't want to enable this either.  In general, you should 
say NO to all of these RPC services that run by default.

Don't run it unless you have to.  Most users don't have to.  So don't do it.
Select YES if you want to enable ypbind, NO if you're smart.





EOF
;;

	nis_master_enable)	${MORE} << EOF
NIS Master Server.

This is used to update the NIS master database and needs to be run by the 
master server for the NIS domain.

Most users should stay away from this and all other RPC options.

Select YES if you know your network uses it and you have reviewed the 
configuration, NO otherwise.








EOF
;;

	rpc_portmap_enable)		${MORE} << EOF
Portmap daemon.

You need portmap if you run RPC/NFS sludge.  

If you don't use any RPC service (you can easily run a box without any
rpc services, in fact you probably should run the box without any of 
this RPC junk), then you should not enable this.

Most users should answer NO, unless they are using NFS.  Portmap has been
vulnerable in the past and will likely be in the future.  Use with caution.

Select YES if you need portmap for other RPC services, NO otherwise.





EOF
;;

	rpc_mountd_enable)		${MORE} << EOF
Mounting daemon.

You really only need mountd if you use NFS.  You must enable mountd before
starting up any NFS sessions.

Again the same thing holds with previous RPC functions, use if you must, but
most users won't want or need this.

Select YES if you choose to run NFS, most should say NO here.








EOF
;;

	rpc_pcnfsd_enable)		${MORE} << EOF
PC NFS daemon.

Yet another RPC based daemon.  This one is for authentication and printer
services with PC/Macs.

This is unecrypted and a potential security risk.

This is another of those darn RPC services that you should stay away from.
Use this if you know what NFS is and how it works and have reviewed the
configuration.

Select NO if you know what NFS does and how it works because if you know how
it works, you aren't likely to want to enable it :)

Select YES if you need compatibilty with PCs running NFS.  Select NO if you
don't have to deal with those pesky PCs.

EOF
;;

	rpc_bwnfsd_enable)		${MORE} << EOF
BWNFSD - another RPC daemon.

If you use this, it's used in conjunction with BWNFS, a client for DOS and
Macs.  It provides basic authentication, printing, and DOS based sharing/
locking.

If you know what it does, you probably won't want to use it.  If you don't know
what it does, you definitely don't want to use it.  

Most people should stay away from this and all those other RPC daemons.

Select YES if you like exploits, NO if you like your box the way it is.





EOF
;;

	sendmail_enable)	${MORE} << EOF
Sendmail - mail daemon

The (in)famous sendmail daemon.  It has a checkered security past, but in
recent years there have been strides to try to make sendmail more secure.

Most users will want to run sendmail with "-q15m" and NOT the default
"-bd -q15m".  When you use the "-bd" argument, you are putting it into the
background and it's actively listening on your machine for incoming connections.
The sendmail arguments will be set later on in the script.  This option here
is only for if you want to run sendmail at all.

Select YES if you want to send mail, NO if you want to look for better options.

We recommend looking into Postfix (free software, better security), exim (free
software focused on security) or qmail (not free software licensed).


EOF
;;

	apmd_enable)		${MORE} << EOF
APMD (Advanced Power Management Daemon).

Apm is used on laptops.  You can suspend your machine and then later
unsuspend it.  This increases battery life since it's not using all of that
processing power while idle.

If you are on a desktop, don't enable this unless you have other weird
circumstances we probably don't want to know about ;)

Select YES if this is a laptop, NO if it's not.







EOF
;;

	kerneld_enable)		${MORE} << EOF
kerneld (Kernel Module Loader).

This will automatically load modules for you.  It's not recommended for
kernels over 2.2.x (ala a default slackware 7 install) so you shouldn't
enable this unless you really need to.

If you want to enable modules, edit /etc/rc.d/rc.modules instead.

Select YES if kernel < 2.2, NO if >= 2.2.








EOF
;;

	loopback_enable)	${MORE} << EOF
Loopback device

The loopback device allows you to connect to network client/server services on
your machine originating from your machine.

This is safe to enable and you really should do so.

Select YES if you are sane, NO if not.









EOF
;;

	ethernet_enable)	${MORE} << EOF
Ethernet device

If you use a ethernet network card (eth0), then you should enable this.

Select YES if you use an ethernet card, NO if you don't.












EOF
;;

	accton_enable)		${MORE} << EOF
Accton - process accounting.

If you wish to keep using accounting, then select YES.  This option is actually
called in the initialization scripts as if you want to discontinue use.

But we have simplified this, so if you want accounting, select YES, if you
want to turn accounting off, select NO.










EOF
;;	

	lpd_enable)		${MORE} << EOF
LPD (line printer daemon).

This is the standard printer daemon.  You will almost definitely need some
filters setup to use the printer effectively. 

Look into filters such as apsfilter, magic filter or ghostscript filter.

When in doubt, check out the linux documentation project for a howto on lpd.

Select YES if you wish to run the printer daemon, NO if you don't want to use
the standard printer daemon.






EOF
;;

	quotas_enable)		${MORE} << EOF
Quotaon - File system quotas 

If you wish to keep running quotas, then select YES here.  The quotas are
for both processing and disk quotas.

You need to setup the quotas before you use them, so make sure you configure
your conf files before enabling it.

Select YES if you have looked at the configuration files, select NO if you
do not wish to run quotas.







EOF
;;

	rc_atalk_enable)	${MORE} << EOF
/etc/rc.d/rc.atalk

If you want to communicate with Macintosh machines over a network, then you
should say YES to this option.

Select YES to talk with MacOS boxes, select NO if you don't have any Macs.











EOF
;;

	rc_cdrom_enable)	${MORE} << EOF
/etc/rc.d/rc.cdrom

If you want to have slackware autodetect and mount your CD-ROM device, then
select YES here.  Be warned: there may be error messages associated with running
this.

You do not need this.  It's not enabled by default.

Select YES if you wish to run the script, NO if not.








EOF
;;

	rc_font_enable)		${MORE} << EOF
/etc/rc.d/rc.font - EGA/VGA console screen fonts

In the default install, it will create /etc/rc.d/rc.font.sample.  You should
edit this file to suite your needs.

This option is not required and generally is safe to run.

Select YES to enable the script, or NO to disable.









EOF
;;

	rc_gpm_enable)		${MORE} << EOF
/etc/rc.d/rc.gpm

GPM is a mouse daemon for using your mouse in the console.

It can cause errors with X but those can be fixed in the XF86Config file by
choosing a different mouse protocol.

Select YES if you want to enable gpm, the console mouse daemon, or NO if you
don't use a mouse or don't want this.








EOF
;;

	rc_httpd_enable)	${MORE} << EOF
/etc/rc.d/rc.httpd

This is the script for starting up Apache webserver. 

By default is run with "apachectl start"

The script you are currently running has some support for securing potential
problem areas with Apache.

Apache has to run as root for a brief time in order to reserve port 80 but
then drops root status.

Select YES if you wish to run a webserver, NO if you have no interest in it.




EOF
;;

	rc_ibcs2_enable)	${MORE} << EOF
/etc/rc.d/rc.ibcs2

iBCS2 (Intel Binary Compatibility Specification 2) is used mainly by 
commercial applications for SCO or SVR4 which run under Linux.

It is not essential and most users will not need to enable this.

Select YES if you need to run SVR4 applications under Linux, NO if you do
not.








EOF
;;

	rc_keymap_enable)	${MORE} << EOF
/etc/rc.d/rc.keymap

This is for enabling different keymaps through the script.

This is also not strictly needed

Select YES if you have to load other keymaps, NO if you don't










EOF
;;

	rc_local_enable)	${MORE} << EOF
/etc/rc.d/rc.local

This could contain anything.  By default, it's a blank file.  It's intended
for the local sysadmin to use to enable services.  It's the last script
to run out of the main initialization scripts.

Most users can use this, but it's only beneficial if you edit it to include
functionality.

Select YES if you have reviewed whats in rc.local, NO if you don't need it.







EOF
;;

	rc_modules_enable)	${MORE} << EOF
/etc/rc.d/rc.modules

This will enable loading of kernel modules at system initialization time.

Unless you recompiled your kernel to include every driver in the kernel
and did not make it accept modules, then you should probably enable this.

Review what it loads.  By default there is not much automatically loaded
except for a PS/2 driver and some other various very common items.

Select YES to enable the script, NO to disable it.






EOF
;;

	rc_netdevice_enable)	${MORE} << EOF
/etc/rc.d/rc.netdevice

In a default slackware install, this file will not be created.  You need
to create and edit it for your network if you use multiple network 
devices.

Select YES if you have created the file and it contains the appropriate 
information, NO if you only have one network card.









EOF
;;

	rc_network_enable)	${MORE} << EOF
/etc/rc.d/rc.network

This script will enable networking.

If you need networking, you should enable this.  Most users should enable
this.

Select YES to enable, NO to disable.









EOF
;;

	rc_samba_enable)	${MORE} << EOF
/etc/rc.d/rc.samba

Samba is a program to allow your Slackware machine to talk to Windows 9x/2000
machines.  It will enable you to have your Slackware box appear as a just
another windows box in the "Network Neighborhood" in Windows.

Select YES if you need to talk with other local windows machines, NO if you 
don't.









EOF
;;

	rc_sysvinit_enable)	${MORE} << EOF
/etc/rc.d/rc.sysvinit

This script is mainly for compatibility.  Some programs assume a typical
sysV initialization structure (/etc/rc.d/rc.0 is a directory which contains
a bunch of individual files that correspond to individual servers, you 
have directories rc.0 through rc.6).

This will help integrate those packages to work with Slackware which uses
a more BSD initialization sequence.

Select YES if you want to enable this compatibility, NO if you do not.






EOF
;;

	rc_serial_enable)	${MORE} << EOF
/etc/rc.d/rc.serial

This script can cause problems with certain hardware.  Use with caution.


Select YES if you need slackware to configure your serial devices, NO if
you do not need this.










EOF
;;

	rc_pcmcia_enable)	${MORE} << EOF
/etc/rc.d/rc.pcmcia

PCMCIA (Personal Computer Memory Card International Association) cards are
used commonly in laptops.  

These are also referred to as "pccards".

Select YES if you have a laptop and wish to enable this script, NO if you don't.









EOF
;;

	*)			${MORE} << EOF
Uknown service: ${DAEMON}.

If you got here, you added something to /etc/rc.d/rc.conf that wasn't there when
this script was written.  That's not necessarily bad, but we cannot give you
any advice on what it is from this script.

We recommend that if you got here and you think this server is standard,
then please e-mail us.  You have just found a bug :)

If not, please refer to your trusty man pages and documentation on whether
you should be running this daemon and if the default configuration is secure.

If you have found a bug, please visit: http://SAStk.sourceforge.net

once your machine is back in multi-user mode of course.
Say YES if you know what this is and how it works, but it's probably more
safe to say NO here and go research what it does.
EOF
;;

esac
}


##################
# Start the work #
##################

${ECHO} "SAStk was run on ${CURRENT_DATE}." >> ${logfile}
${ECHO} "${SASTK_ID}" >> ${logfile}
${CLEAR}
${CAT} << EOF
********************************************************************************
*                       SAStk hardening Section
********************************************************************************

This section of SAStk will apply some basic hardening to your system.

You will be asked a series of questions and the changes will be applied as
you go through.

Please read each question carefully before you answer it.
At the present time this script will not undo changes made in the hardening 
section of SAStk
If you decide to enable a particular feature then the next time $0
is run you will not be asked that question again.
If you answer no to one of the questions and change your mind you may run 
$0 again as many time as you need to.

Please press enter to begin the hardening section of SAStk
EOF
read junk

${CLEAR}
if [ -z "$(${GREP} -s 'consent to the aforementioned monitoring' /etc/issue.net)" ]; then
${CAT} << EOF
       Checking /etc/issue.net
********************************************************************************

If you do not have an /etc/issue.net, we can provide you with one.  Here's
what it will look like:

*****************************************************
This system is for the use of authorized users only.
     	   All connections are Logged !!
   Keyboard input will be monitored in the event 
     of a real or suspected security incident.

 Use of this system constitutes understanding and 
    consent to the aforementioned monitoring. 
*****************************************************

If you would like to add this warning to the logins, say YES, or else NO.






********************************************************************************
EOF
check_answer "to answer if you want /etc/issue.net if you don't have one"
#Set up /etc/issue.net
[ -f /etc/issue.net -a ! -f "${BKUP}/etc/issue.net" ] && \
       ${CP} -pf /etc/issue.net "${BKUP}/etc/issue.net"
${ECHO} "Adding warning to /etc/issue.net"
${ECHO} "Adding warning to /etc/issue.net" >> ${logfile}
${CAT} > /etc/issue.net << EOF

*****************************************************
This system is for the use of authorized users only.
     	   All connections are Logged !!
   Keyboard input will be monitored in the event 
     of a real or suspected security incident.

 Use of this system constitutes understanding and 
    consent to the aforementioned monitoring. 
*****************************************************

EOF
    update_md5 "/etc/issue.net"
fi

${CLEAR}
if [ -f /etc/lilo.conf -a -z "$(${GREP} -s '^password' /etc/lilo.conf)" ]; then
    ${CAT} << EOF
      Checking LILO
********************************************************************************

If you want to add a password to LILO to prevent someone passing parameters
to your kernel at boot time then say YES here.

This will not prompt for a password during a normal bootup but it should prevent
people from booting directly to a shell or straight into Single User Mode.
 
If you want to add a password to LILO so that others cannot boot your system 
without the password then you will need to comment out the word "restricted"
from your /etc/lilo.conf file and run 'lilo' to update it.

This is just a precaution, it's almost impossible to secure the machine if
someone has access to the hardware.

But it will keep most people away provided your BIOS is setup to boot from
the hard drive first, instead of a floppy or CDROM.


Most users should say YES and set a password.



********************************************************************************
EOF
check_answer "to answer if you want LILO to have a bootup password"
    #Add password to Lilo
    if [ ! "${some_answer}" = "NO" ]; then
        #make a backup
        [ ! -f "${BKUP}/etc/lilo.conf" ] && \
        ${CP} -p /etc/lilo.conf "${BKUP}/etc/lilo.conf"
        # Make sure the user enters at least 8 characters.
        # And also make sure they typed it twice in a row correctly.
        # Using stty, we can hide the password.
        until [ $((${#pass})) -ge 8 -a X"${validate}" = X"1" ];  do
            ${ECHO}  "Enter the password you would like to use"
            ${ECHO}  "You must enter a password of at least 8 characters and not all one case"
            ${ECHO} -n "password: "
            ${STTY} -echo
            read pass
            ${STTY} echo
            ${ECHO} "Please confirm the password by typing it again"
            ${ECHO} -n "password: "
            ${STTY} -echo
            read pass2
            ${STTY} echo
            if [ X"${pass2}" = X"${pass}" -a $((${#pass})) -ge 8 ]; then
               validate=1
            elif [ X"${pass2}" = X"${pass}" -a ! $((${#pass})) -ge 8 ]; then
               ${ECHO} " "
               ${ECHO} "The entries matched, but"
               ${ECHO} "Your password was not at least 8 characters"
               ${ECHO} " "
            elif [ ! X"${pass2}" = X"${pass}" -a $((${#pass})) -ge 8 ]; then
               ${ECHO} " "
               ${ECHO} "Your password was at least 8 characters"
               ${ECHO} "But your entries did not match."
               ${ECHO} " "
            else
               ${ECHO} " "
               ${ECHO} "The entries did not match and the length was not 8 characters"
               ${ECHO} " "
            fi
        done
        ${CP} -p /etc/lilo.conf "${TMPDIR}/lilo.conf"
        ${SED} -e '/^boot/i\
restricted\
password='"${pass}" "${TMPDIR}/lilo.conf" >/etc/lilo.conf
        ${CHMOD} 0600 /etc/lilo.conf
        ${ECHO} "Adding Password to /etc/lilo.conf" >> ${logfile}
        ${LILO} -v 1>> ${logfile} 2>> ${errlog}
        pass="null"; pass2="null"; unset pass; unset pass2
            update_md5 "/etc/lilo.conf"
    fi
fi

${CLEAR}
if [ ! -f /root/.bash_logout -o -z "$(${GREP} -s '^/usr/bin/clear$' /root/.bash_logout)" ]; then
${CAT} << EOF
       Checking root's .bash_logout
********************************************************************************

If you want to have your screen cleared after you logout, then say YES here.

Most users should say YES here as it will prevent others from looking at what
you had previously typed.

It's not too useful because anyone could always do 'left_alt + pgup' to view
what was in the buffer before.













********************************************************************************
EOF
check_answer "to answer if you want root's screen to clear after logout"
#Add clear to .bash_logout
if [ ! "${some_answer}" = "NO" ]; then
    if [ ! -f /root/.bash_logout ]; then
        ${ECHO} "Adding clear screen command to /root/.bash_logout" \
              1>> ${logfile} 2>> ${errlog}
        ${ECHO} "${CLEAR}" > /root/.bash_logout
        ${ECHO} "Adding clear to /root/.bash_logout"
    elif [ ! X"$(${GREP} "^/usr/bin/clear$" /root/.bash_logout)" = X"/usr/bin/clear" ]; then
        ${ECHO} "Adding clear screen command to /root/.bash_logout" \
              1>> ${logfile} 2>> ${errlog}
        ${ECHO} "${CLEAR}" >> /root/.bash_logout
        ${ECHO} "Adding clear to /root/.bash_logout"
            update_md5 "/root/.bash_logout"
    fi
fi
fi

${CLEAR}
if [ -n "$(${GREP} '^\*' /var/X11R6/lib/xdm/Xaccess)" -o \
-z "$(${GREP} 'nolisten\ tcp' /usr/X11R6/bin/startx)" ]; then
${CAT} << EOF
             Checking X login sessions
********************************************************************************

Normally, X logins are allowed on this system.  This can be a potential
security hazard because if you setup xhost or xauth incorrectly, anyone
could be able to connect to your X server.  This is normally on port 6000 tcp.

Note: This X window system fix currently only works for 3.3.x.  It has not
been updated for X 4.0.x yet.

Would you like to disable XDM (graphical login) and regular xinit from 
remote locations?  You will still have full use of XFree86, but connections
will only be made over Unix domain sockets which are localhost only.

You should say "YES" if you do not plan on using X remotely.

Select 'YES' to disable remote logins, 'NO' to enable remote logins.






********************************************************************************
EOF
check_answer "to answer whether you want to allow remote X connections."
# Stop remote X-login screens
if [ ! "${some_answer}" = "NO" ]; then
    if [ -f "/var/X11R6/lib/xdm/Xaccess" ]; then
        ${ECHO} "Stopping remote X-login screens for xdm" >> ${logfile}
        ${ECHO} "Stoping remote X-login screens"
        ${CP} -pf /var/X11R6/lib/xdm/Xaccess "${TMPDIR}/Xaccess"
        ${SED} -e 's/^\*/#*/g' "${TMPDIR}/Xaccess" > \
            /var/X11R6/lib/xdm/Xaccess 2>> ${errlog}
            update_md5 "/var/X11R6/lib/xdm/Xaccess"
    fi
    if [ -f "/usr/X11R6/bin/startx" ]; then
        ${ECHO} "Stopping remote X-login screens startx" >> ${logfile}
        ${CP} -pf /usr/X11R6/bin/startx "${TMPDIR}/startx"
        if [ X"$(${GREP} 'serverargs=\".*-nolisten tcp\"' /usr/X11R6/bin/startx)" = "X" ]; then
            ${SED} -e 's/^serverargs=\"/serverargs=\"-nolisten tcp/' \
                "${TMPDIR}/startx" > /usr/X11R6/bin/startx 2>> ${errlog}
                 ${CHMOD} 0755 /usr/X11R6/bin/startx 2>> ${errlog}
                update_md5 "/usr/X11R6/bin/startx"
        fi
    fi
fi
fi

${CLEAR}
if [ ! -f "${BKUP}/fileperm.bak" ]; then
${CAT} << EOF
          Checking file permissions
********************************************************************************

In a normal installation, the file permissions are typically weak for most
situations.

Unless you have need for weak permissions, you should select 'YES' here.

Select 'YES' if you would like us to tighten up the permissions, 'NO' if you
would like to keep them the same as the default install.













********************************************************************************
EOF
check_answer "to answer whether you want to tighten up file permissions"
# Set restrictive file permissions
if [ ! "${some_answer}" = "NO" ]; then
    if [ ! -f "${BKUP}/fileperm.bak" ];then
       ${ECHO} "Backing up old file permissions to ${BKUP}/fileperm.bak" 
       ${ECHO} "backup of old file permissions is ${BKUP}/fileperm.bak" >> ${logfile}
#       ${AWK} -F: '{
#           system("./grokmode.sh "$4)
#       }' < ./fileperm 1>> ${BKUP}/fileperm.bak 2>> ${errlog}
    for file in "$(${AWK} -F: '{print $4}' < ./fileperm)"; do
    ${FIND} ${file} -printf '%m:%u:%g:%p \n' 1>> "${BKUP}/fileperm.bak" 2>> ${errlog}
    done
    fi
    ${ECHO} "Setting restrictive file permissions" >> ${logfile}
    ${ECHO} "Setting restrictive file permissions" 
    ${AWK} -F: '{
        print "chmod "$1" "$4
        print "chown "$2"."$3" "$4
        system("/bin/chmod "$1" "$4)
	system("/bin/chown "$2"."$3" "$4)
    }' < ./fileperm 1>> ${logfile} 2>> ${errlog}
fi
fi

${CLEAR}
# Secure /etc/inetd.conf
# This is only temporary.  Add functionality later to allow answering for every
# service, not just a default allow or default deny.
if [ -n "$(${GREP} -v '^#' /etc/inetd.conf)" ]; then 
${CAT} << EOF
          Determining if inetd should have disabled services
********************************************************************************

/etc/inetd.conf has many servers that you probably do NOT want to run.  These
are turned on by default in the slackware installation.  Most users do NOT
want to run these services because:

1.  They will give out more information about you than you would like.
2.  They have been security problems in the past.

You will find that many experienced Linux users will turn off all of these
services right after they install, particularly the RPC services.

Select YES if you would like to turn off these unnecessary services or NO to
keep your machine exposed and the services enabled.








********************************************************************************
EOF
check_answer "to answer whether you want to turn off /etc/inetd.conf"
if [ ! "${some_answer}" = "NO" ]; then
    ${ECHO} "Securing /etc/inetd.conf"  >> ${logfile}

    # Make a backup
    [ ! -f "${BKUP}/etc/inetd.conf" ] && \
         ${CP} -p /etc/inetd.conf "${BKUP}/etc/inetd.conf"

    ${CP} -pf /etc/inetd.conf "${TMPDIR}/inetd.conf"
    ${SED} -e '/#/!s/^/#\ /g' "${TMPDIR}/inetd.conf" > /etc/inetd.conf 2>> ${errlog}
   update_md5 "/etc/inetd.conf"
fi
fi

${CLEAR}
# Are we sure about disabling devices?  What about FIFOs (named pipes)?
if [ -n "$(${GREP} '/tmp' /etc/fstab)" -a \
-n "$(${GREP} '/tmp.*defaults' /etc/fstab)" ]; then
${CAT} << EOF
        Securing /tmp if mounted on a separate partition.
********************************************************************************

The directory /tmp has shared data between users stored temporarily.  By default
there are no restrictions on what operations can be done in /tmp at the 
/etc/fstab level.

If you would like to secure /tmp by disabling:

SUID [(set user id) common exploit area if code is malformed]
Execution [no need to execute anything in /tmp, should be for scratch files
Character or block devices [those should all be in /dev]

then enable this.  Most users should change their current setup because there
is no reason to keep /tmp without these restrictions if it's a partition.

As previously stated, this will not take effect if your /tmp is not mounted
on it's own partition.





********************************************************************************
EOF
check_answer "to answer whether you want to secure /tmp"
if [ ! "${some_answer}" = "NO" ]; then
    if [ -n "$(${GREP} '/tmp' /etc/fstab)" ]; then
    ${ECHO} "Securing /tmp in /etc/fstab" >> ${logfile}
        # Make a backup
        [ ! -f "${BKUP}/etc/fstab" ] && ${CP} -p /etc/fstab "${BKUP}/etc/fstab"
        ${CP} -pf /etc/fstab ${TMPDIR}/fstab
        ${SED} -e '/\/tmp/s/defaults/rw,nosuid,noexec,nodev/' ${TMPDIR}/fstab > \
             /etc/fstab 2>> ${errlog} 
        ${ECHO}  "/tmp secured"
           update_md5 "/etc/fstab"
    fi
fi
fi

${CLEAR}
if [ -n "$(${GREP} '/home' /etc/fstab)" -a \
-n "$(${GREP} '/home.*defaults' /etc/fstab)" ]; then
${CAT} << EOF
        Checking /home in fstab
********************************************************************************

If your /home is mounted on its own partition, then this could apply to you.
By default, there are no /etc/fstab level restrictions on the files in /home.

This option will disable SUID [set user id] programs because they are a common
exploit area.  The linux kernel will not allow for suid shell scripts because
they are so dangerous, but it will allow for suid C programs for instance.

Suid programs should NOT be available to users.  The only suid programs should
be checked by the system administrator and installed in one of the /sbin or
/usr/sbin directories normally.   These can be dangerous programs.

The program, no matter who executed by, will run as the person who has set the
suid bit on it.  So root suid programs are especially dangerous.

The other option disabled are devices.  Devices should only be in /dev or
/tmp if they are FIFOs for instance.

Most users should answer YES here to disable suid programs in /home.
Select YES to disable suid on the /home partition if you have it mounted 
on its own partition.
********************************************************************************
EOF
check_answer "to answer whether you want to secure /home"
if [ ! "${some_answer}" = "NO" ]; then
    if [ -n "$(${GREP} '/home' /etc/fstab)" ]; then
    ${ECHO} "Securing /home in /etc/fstab" >> ${logfile}
       # Make a backup
       [ ! -f "${BKUP}/etc/fstab" ] && ${CP} -p /etc/fstab "${BKUP}/etc/fstab"
       ${CP} -pf /etc/fstab ${TMPDIR}/fstab
       ${SED} -e '/\/home/s/defaults/rw,nosuid,nodev/' ${TMPDIR}/fstab > \
            /etc/fstab 2>> ${errlog}
       ${ECHO}  "/home secured"
           update_md5 "/etc/fstab"
    fi
fi
fi

${CLEAR}
if [ -n "$(${GREP} -s '^ca::ctrlaltdel' /etc/inittab)" ];then
${CAT} << EOF
        Checking to disable control+alt+delete
********************************************************************************

Normally pressing control, alt, and delete at the same time will send the
system into runlevel 6 -- rebooting the machine.

If you would like to disable this (control+alt+delete won't do anything) then
select YES for this option, or NO otherwise.















********************************************************************************
EOF
check_answer "to answer whether you want to disable ctrl+alt+del"
if [ ! X"${some_answer}" = X"NO" ]; then
    ${ECHO} "Disabling ctrl-alt-del" >> ${logfile}

    # Make a backup
    if [ ! -f "${BKUP}/etc/inittab" ]; then
        ${CP} -p /etc/inittab ${BKUP}/etc/inittab
    fi

    ${CP} -pf /etc/inittab "${TMPDIR}/inittab"
    ${SED} -e '/Three Finger Salute/,/ctrlaltdel/{
            /Three/i\
# Disabled by SAStk
           /ctrlaltdel/s/^/#/
    }' "${TMPDIR}/inittab" > "/etc/inittab" 2>> ${errlog}
    ${ECHO} "CTRL+ALT+DEL Disabled "
    update_md5 "/etc/inittab"
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s '^umask 077' /etc/profile)" ]; then
${CAT} << EOF
      Checking umask in /etc/profile
********************************************************************************

By default, the umask of users is 022.  What a umask is, is a reverse of a 
chmod value.  This umask value is for users and will set the "default"
permissions for newly created files.

So 022 will by default deny others in your group, and everyone else on the
system from writing to your files, but the other permissions (executing and
reading) are left up to the discretion of whatever program is setting this value

Enable this if you want to not allow any other users besides yourself read,
write, or execute any of your files by default.  Since access is 
discretionary, you can later enable or disable access to your files if you want,
this is just the default.

Note: This will not prevent root from anything of course.  And it will not
fix the permissions of your files that are already created or your own
personal .profile file.
You should edit these on your own (see chmod).

Select YES if you wish to keep your current configuration, or NO to not allow
anyone to view your newly created files as a general rule.
********************************************************************************
EOF
check_answer "to answer whether you want to set umask 077 in /etc/profile"
if [ ! "${some_answer}" = "NO" ]; then
    ${ECHO} "Setting umask in /etc/profile to 077" >> ${logfile}
    # Make a backup
    if [ ! -f "${BKUP}/etc/profile" ]; then
        ${CP} -p /etc/profile "${BKUP}/etc/profile"
    fi

    ${CP} -pf /etc/profile "${TMPDIR}/profile"
    ${SED} -e '/^umask/{
            /^umask/i\
    # Changed by SAStk to 077
            s/022/077/
    }' "${TMPDIR}/profile" > /etc/profile 2>> ${errlog}
    ${ECHO} "Umask set to 077"
    update_md5 "/etc/profile"
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s 'settings added by SAStk' /etc/profile)" ]; then
${CAT} << EOF
        Checking user restrictions in /etc/profile
********************************************************************************

This option is whether you want to enable user restrictions by default.  These
are general guidelines for users and not hard and fast rules.

For many users they will obey these limits and that's all you are really
looking for.

If you need more restrictive control over what the user's do with the machine
you should look to alternatives such as PAM.

Select YES to enable these shell history limits that generally restrict
users from using too large of a history, or NO if you don't want to have
any control over what they do.  The default is 500.

This option only applies to korn and bash (bourne again) shells.






********************************************************************************
EOF
check_answer "to answer whether you want user restrictions in /etc/profile"
if [ ! X"${some_answer}" = X"NO" ]; then
    ${ECHO} "Adding user restrictions to /etc/profile" >> ${logfile}

    # Make a backup 
    if [ ! -f "${BKUP}/etc/profile" ]; then
        ${CP} -p /etc/profile "${BKUP}/etc/profile"
    fi

    ${CAT} >> /etc/profile << EOF

#
# Soft history limits added by SAStk
# ${SASTK_ID}
# at ${CURRENT_DATE}
#
HISTFILESIZE=20
HISTSIZE=20

EOF
    update_md5 "/etc/profile"
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s 'umask 077' /etc/csh.login)" ]; then
${CAT} << EOF
       Change umask in /etc/csh.login
********************************************************************************
 
By default, the umask for the system in general is 022.  This means that when
an application/makefile creates a file, then it is subject to the umask.

This means for instance, that if it is created with permissions 777, then
because of your umask, it will automatically adjust the mask to 755.

A umask restrictions permissions, so 022 restricts write permission for people
in your group and for the rest of the users on the system.  But they could
still read and execute your files if you allow for it.

Because Unix has discretionary access, you can however change the permissions
whenever you want to allow others to read/write/execute your files.  This is
just the default setting that this question is asking about.

Select NO if you would like to allow other users to read and execute your 
files  or YES if you want to change this so that only you can read them.




********************************************************************************
EOF
check_answer "to answer whether you want to change the umask in csh.login"
# Change umask in csh.login
if [ ! X"${some_answer}" = X"NO" ]; then
    ${ECHO} "Changing umask in /etc/csh.login to 077" >> ${logfile}

    # Make a backup
    if [ ! -f "${BKUP}/etc/csh.login" ]; then
        ${CP} -p /etc/csh.login "${BKUP}/etc/csh.login"
    fi

    ${CP} -pf /etc/csh.login "${TMPDIR}/csh.login"
    ${SED} -e '/umask/{
            /umask/i\
     # Changed by SAStk to 077
            s/022/077/
    }' "${TMPDIR}/csh.login" > /etc/csh.login 2>> ${errlog}

    if [ ! -f "${BKUP}/etc/csh.login" ]; then
        ${CP} -p /etc/csh.login "${BKUP}/etc/csh.login"
    fi

    update_md5 "/etc/csh.login"
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s 'PrivacyOptions\=goaway' ${SENDMAILDIR}/sendmail.cf)" ]; then
${CAT} << EOF
        Sendmail - allow remote connections?
********************************************************************************

Also, this option will set the vrfy and expn options.  These are for the 
confPRIVACY_FLAGS in the sendmail configuration.

The problem of vrfy is that sendmail will verify if a user is valid.  This
is giving out too much information about your system to others.  For instance,
people can connect to your sendmail port and try random users until it is
a valid username.

This option will turn on 'goaway' which does more than just turn off vrfy.

goaway - Is a shortcut for:
     all authwarnings, noexpn, novrfy, needmailhelo, needexpnhelo, needvrfyhelo.

This is from sendmail.org about noexpn:
Commercial spam programs can make use of the EXPN command to find valid
addresses on your system and increase the amount of junk mail your site receives

Select YES if you want to enable this option to prevent people from gathering
information about users/emails on your system, or NO to allow people to 
potentially find out valid usernames/emails.
********************************************************************************
EOF
check_answer "to answer whether you want sendmail configured more securely"
# All authwarnings, noexpn, novrfy, needmailhelo, needexpnhelo, needvrfyhelo
if [ ! "${some_answer}" = "NO" ]; then
    ${ECHO} "Sendmail: authwarnings, noexpn, novrfy, needmailhelo, needexpnhelo, needvrfyhelo" >> ${logfile}

    # Make a backup
    if [ ! -f "${BKUP}${SENDMAILDIR}/sendmail.cf" ]; then
        ${CP} -p "${SENDMAILDIR}/sendmail.cf" "${BKUP}${SENDMAILDIR}/sendmail.cf"
    fi

    ${CP} -pf "${SENDMAILDIR}/sendmail.cf" "${TMPDIR}/sendmail.cf"
    ${SED} -e '/^O\ PrivacyOptions/s/authwarnings/goaway/' \
        "${TMPDIR}/sendmail.cf" > "${SENDMAILDIR}/sendmail.cf" 2>> ${errlog}

    # Send SIGHUP to sendmail? 
    [ ! -z "$(${PIDOF} sendmail)" ] && ${KILL} -HUP $(${PIDOF} sendmail)
    update_md5 "${SENDMAILDIR}/sendmail.cf"
fi
fi

${CLEAR}
    if [ -n "$(${GREP} -s 'DaemonPortOptions' ${SENDMAILDIR}/sendmail.cf)" ]; then
    if [ -z "$(${GREP} -s '#O\ DaemonPortOptions' ${SENDMAILDIR}/sendmail.cf)" ];then
${CAT} << EOF
        Checking sendmail listen port
********************************************************************************

By default, sendmail is setup in a background daemon mode.  This can allow
for others to connect to your sendmail server and bounce mail off of it.  It
also listens in on port 587 (SMTP AUTH) for incoming connections.

If you do not want to have it in daemon mode, then set this to YES.  You can
still send mail to others, but it disables relaying from external hosts.

Most users should select YES unless they run mailing lists.









Select YES if you want to turn off listening on a port for incoming connections,
or NO if you run mailing lists.

********************************************************************************
EOF
check_answer "to answer whether you want to disable sendmail for remote connects"
# Stop sendmail from listening to port 
if [ ! "${some_answer}" = "NO" ]; then
    old_sendmail_args=$(${GREP} 'sendmail_args=\".*-bd' /etc/rc.d/rc.conf)
    if [ ! X"${old_sendmail_args}" = "X" -a -f /etc/rc.d/rc.conf ]; then
        new_sendmail_args=$(${ECHO} "${old_sendmail_args}" | ${AWK} -F ' -bd ' '{print$1 $3}')
        ${SED} -e "s/${old_sendmail_args}/${new_sendmail_args}/" /etc/rc.d/rc.conf > /etc/rc.bak
        ${RM} /etc/rc.d/rc.conf && ${MV} /etc/rc.bak /etc/rc.d/rc.conf
    fi

    if [ "${version}" = "7.1.0" ]; then
       ${ECHO} " Stopping sendmail from listening to port 587" >> ${logfile}
       # Make a backup
       if [ ! -f "${BKUP}${SENDMAILDIR}/sendmail.cf" ]; then
          ${CP} -p "${SENDMAILDIR}/sendmail.cf" "${BKUP}${SENDMAILDIR}/sendmail.cf"
       fi

       ${CP} -pf "${SENDMAILDIR}/sendmail.cf" "${TMPDIR}/sendmail.cf"
       ${SED} -e '/^O\ DaemonPortOptions/s/^/#/g' "${TMPDIR}/sendmail.cf" > \
              "${SENDMAILDIR}/sendmail.cf" 2>> ${errlog}
           update_md5 "${SENDMAILDIR}/sendmail.cf"
    fi
fi
    fi
    fi

${CLEAR}
if [ -z "$(${GREP} '^ALL:ALL' /etc/hosts.deny)" ]; then
${CAT} << EOF
          Checking /etc/hosts.deny
********************************************************************************

/etc/hosts.deny is used by inetd servers and by TCP wrappers.  It determines
who is denied access from which services.

By default, hosts.deny is empty.  If you select this option to YES, it will
set the option to ALL:ALL except localhost so that no one can remotely
connect to your services that use /etc/hosts.deny as a guide for who to deny.














********************************************************************************
EOF
check_answer "to answer whether you want to tighten up /etc/hosts.deny"
# Modify /etc/hosts.deny
if [ ! "${some_answer}" = "NO" ]; then
    if [ -z "$(${GREP} '^ALL:ALL' /etc/hosts.deny)" ]; then
         ${ECHO} "Modifing /etc/hosts.deny" >> ${logfile}
        # Make a backup
        if [ ! -f "${BKUP}/etc/hosts.deny" ]; then
            ${CP} -p /etc/hosts.deny "${BKUP}/etc/hosts.deny"
        fi
        ${CP} -pf /etc/hosts.deny "${TMPDIR}/hosts.deny"
        ${SED} -e '/^#\ End/i\
ALL:ALL except localhost' "${TMPDIR}/hosts.deny" > /etc/hosts.deny 2>> \
             ${errlog}
            update_md5 "/etc/hosts.deny"
    fi
fi
fi

${CLEAR}
if [ -n "$(${CAT} /etc/hosts.allow | ${GREP} -v '^#')" ]; then
${CAT} << EOF
          Checking uncommented lines in /etc/hosts.allow
********************************************************************************

This option will print out the uncommented lines in /etc/hosts.allow, basically
everyone who you are allowing access to on the system through hosts.allow.

We cannot alter these values in the script because it could break how your
network works currently.  

But you should review the allowed people in hosts.allow to see if everyone
on that list is trusted.







Select YES if you want to view this list, or NO if you don't.




********************************************************************************
EOF
check_answer "to answer whether you want to view /etc/hosts.allow"
if [ ! "${some_answer}" = "NO" ]; then
    ${CLEAR}
    ${CAT} << EOF
********************************************************************************
${SASTK_ID}
********************************************************************************

The following lines in /etc/hosts.allow are uncommented.
(If you don't see anything, that is great).  Make sure 
you want to keep these.  Sorry, but you will have to
remove any unwanted lines yourself.

$(${CAT} /etc/hosts.allow | ${GREP} -v "^#") 


EOF
    ${ECHO} "Please hit enter to continue"
    ${ECHO} " These lines are uncommented in /etc/hosts.allow"  >> ${logfile}
    ${CAT} /etc/hosts.allow | ${GREP} -v "^#" >> ${logfile} 2>> ${errlog}
    ${ECHO} "End of /etc/hosts.allow"  >> ${logfile}
    read junk
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s 'Network restrictions added by SAStk' /etc/rc.d/rc.local)" ]; then
${CAT} << EOF
       Checking network restrictions in /etc/rc.d/rc.local
********************************************************************************

If you select this option, it will alter /etc/rc.d/rc.local so that more
restrictive and protective settings are enabled in the handling of the TCP/IP
stack for more sane values.

For instance, we turn off source routing of IP packets because this is 
generally not wanted and can be used for purposes outside of what it was
originally designed.

Most users should select this option YES, or NO if they know which values
to set in /proc/sys/net/ipv4.


This currently is only implemented for IP version 4.







********************************************************************************
EOF
check_answer "to answer whether you want network restrictions in /etc/rc.d/rc.local"
# Add networking restrictions to rc.local
if [ ! "${some_answer}" = "NO" ]; then

if [ -z "$(${GREP} -s 'Network restrictions added by SAStk' /etc/rc.d/rc.local)" ]; then
    ${ECHO} "Adding networking restrictions to ${RC}/rc.local" >> ${logfile}

   # Make a backup
   if [ ! -f "${BKUP}${RC}/rc.local" ]; then
        ${CP} -p "${RC}/rc.local" "${BKUP}${RC}/rc.local"
   fi

   ${CAT} >> "${RC}/rc.local" << EOF

#
# Network restrictions added by SAStk
# ${SASTK_ID}
#
[ -f /proc/sys/net/ipv4/tcp_cookies ] && \\
${ECHO} 1 > /proc/sys/net/ipv4/tcp_cookies
[ -f /proc/sys/net/ipv4/icmp_echo_ignore_broadcasts ] && \\
${ECHO} 1 > /proc/sys/net/ipv4/icmp_echo_ignore_broadcasts
[ -f /proc/sys/net/ipv4/ip_always_defrag ] && \\
${ECHO} 1 > /proc/sys/net/ipv4/ip_always_defrag

for i in /proc/sys/net/ipv4/conf/*/rp_filter; do
    ${ECHO} 1 > \$i
done

for i in /proc/sys/net/ipv4/conf/*/accept_source_route; do
    ${ECHO} 0 > \$i
done

for i in /proc/sys/net/ipv4/conf/*/log_martians; do
    ${ECHO} 1 > \$i
done

EOF
    ${ECHO} "Added Network restrictions to rc.local"
    update_md5 "/etc/rc.d/rc.local"
	fi
fi
fi

${CLEAR}
if [ -z "$(${GREP} '^nospoof on' /etc/host.conf)" ]; then
${CAT} << EOF
       Checking nospoof in /etc/host.conf
********************************************************************************

This option will try to prevent hostname spoofing from remote hosts.

Most users should enable this.














Select YES if you want to enable this, or NO if you don't.


********************************************************************************
EOF
check_answer "to answer whether you want nospoof on in /etc/host.conf"
# Add nospoof on to /etc/host.conf
if [ ! "${some_answer}" = "NO" ]; then
                # Check for changes not made by us
#                check_md5 "/etc/host.conf"
	if [ -z "$(${GREP} '^nospoof on' /etc/host.conf)" ]; then
   	    ${ECHO} "Adding \"nospoof on\" to /etc/host.conf" >> ${logfile}
   	    ${ECHO} "Adding \"nospoof on\" to /etc/host.conf" 
    	    # Make a backup
            if [ ! -f "${BKUP}/etc/host.conf" ]; then
                ${CP} -p "/etc/host.conf" "${BKUP}/etc/host.conf"
            fi
            ${CAT} >> /etc/host.conf << EOF

#
# Added by SAStk
# ${SASTK_ID}
# at ${CURRENT_DATE}
#
nospoof on

EOF
               update_md5 "/etc/host.conf"
	fi
fi
fi

${CLEAR}
if [ "$(${GREP} 'root' /etc/shadow | ${AWK} -F: '{print $5}')" != "45" ]; then
${CAT} << EOF
      Checking for password aging
********************************************************************************

This option will turn on password aging.  Password aging makes users change
their password after a period of time.  

If you answer YES here we will set the following values.

-x 45 maximum number of days a password will be valid for is 45.

-n 0  there is no miminmum number of days before you can change your password.

-w 7 you will get seven days warning before your password expires.

Most users should enable this as it's very useful.






Select YES to enable password aging, or NO to keep it the way it is.

********************************************************************************
EOF
check_answer "to answer whether you want password aging"
# Enable password aging
if [ ! "${some_answer}" = "NO" ]; then
    # Check to see it has already been enabled.
    # We can do something with this later.
    if [ -n $(${GREP} "root" /etc/shadow | ${AWK} -F: '{print $5}') ]; then
        ${ECHO} "Password aging has already been set.  We will make our changes anyways." \
            >> ${logfile}
    fi

    ${ECHO} "Enabling password aging on root and user accounts" >> ${logfile}
    ${PASSWD} -x 45 -n 0 -w 7 root
# The UID should be 1---, but if it's a huge installation, there could be
# over 9999 users, so use the extended regex with {3,} to account for that.
    for user in $(${EGREP} '[1-9][0-9][0-9][0-9]' /etc/passwd | ${CUT} -d':' -f1); do
        ${PASSWD} -x 45 -n 0 -w 7 "${user}"
    done
fi
fi

${CLEAR}
if [ -n "$(${GREP} -s ':$' /etc/passwd)" ]; then
${CAT} << EOF
       Checking disabled logins to system accounts
********************************************************************************

If you enable this, then system accounts are disabled for login.  This should
be generally done because your normal users will have higher UIDs by 
convention. 

The system accounts are not meant for login anyway.  They are for the system
and created so that they can preform a specific task.










Select YES if you want to disable system accounts (not the same thing as 
user accounts) or NO if you want to keep them the way they are.


********************************************************************************
EOF
check_answer "to answer whether you want to disable system accounts"
# Disable login to system accounts
if [ ! "${some_answer}" = "NO" ]; then
    ${ECHO} "Disabling logins to system accounts" >> ${logfile}

    # Don't Make a backup
    # if [ ! -f "${BKUP}/etc/passwd" ]; then
    #     ${CP} -p /etc/passwd "${BKUP}/etc/passwd"
    # fi

    ${CP} -pf /etc/passwd "${TMPDIR}/passwd"
    ${SED} -e '/:1:/,/:99:/ {
        /:$/s/$/\/bin\/false/
        s/bash/false/
        }' "${TMPDIR}/passwd" > /etc/passwd 2>> ${errlog}
   # update_md5 "/etc/passwd"
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s 'Modified by SAStk' /etc/login.defs)" ]; then
${CAT} << EOF
       Checking settings in /etc/login.defs
********************************************************************************

This option will alter /etc/login.defs for more secure values.

Here's what it will change:
-------------------------------------
option          |   Previous -> New
-------------------------------------
umask:               022    ->  077
log ok logins:       no     ->  yes
default home:        yes    ->  no
password aging days: 99999  ->  45
password min length: 5      ->  8
change finger info:  <comment out>






Select YES to enable the above, NO to keep the previous values.

********************************************************************************
EOF
check_answer "to answer whether you want better values in /etc/login.defs"
# Modify /etc/login.defs
if [ ! "${some_answer}" = "NO" ]; then
    ${ECHO} "Modifying /etc/login.defs" >> ${logfile}

    # Make a backup
    if [ ! -f "${BKUP}/etc/login.defs" ]; then
        ${CP} -p /etc/login.defs "${BKUP}/etc/login.defs"
    fi

    ${CP} -pf /etc/login.defs "${TMPDIR}/login.defs"
    ${SED} -e '
        /LOG_OK_LOGINS/s/no/yes # Modified by SAStk/
        /UMASK/s/022/077 # Modified by SAStk/
        /DEFAULT_HOME/s/yes/no # Modified by SAStk/
        /PASS_MAX_DAYS/s/99999/45 # Modified by SAStk/
        /PASS_MIN_LEN/s/5/8 # Modified by SAStk/
        /CHFN_RESTRICT/s/^/#/' "${TMPDIR}/login.defs" > /etc/login.defs 2>> ${errlog}
    update_md5 "/etc/login.defs"

    # FAILLOG is enabled but the file is missing
    [ ! -f /var/log/faillog ] && ${TOUCH} /var/log/faillog
fi
fi

${CLEAR}
if [ -z "$(${GREP} -s '^root:ALL EXCEPT GROUP wheel:DENY' /etc/suauth)" ]; then
${CAT} << EOF
       Checking for /etc/suauth 
********************************************************************************

The  file  /etc/suauth is referenced whenever the su command is called.
It can change the behaviour of the su command, based upon
   1) the user su is targetting
   2) the user executing the su command (or any groups he might be a member of)

By default all users can execute the su command, and possibly brute force a 
password.
There are many different scenarios in which having the default setting can be 
harmful or result in "bad things".. therefore we recommend only allowing people
in the 'wheel' group access to su to root.



Answer Yes to this question if you would like to restrict su to root to the 
wheel group only.




********************************************************************************
EOF
check_answer "to answer whether you want to restrict su to the wheel group"
# Adding wheel group only to /etc/suauth
if [ ! "${some_answer}" = "NO" ]; then

   # Make a backup
   if [ ! -f "${BKUP}/etc/suauth" -a -f "/etc/suauth" ]; then
        ${CP} -p "/etc/suauth" "${BKUP}/etc/suauth" 2>> ${errlog}
   fi
       if [ ! -f "/etc/suauth" -a ! -f "${BKUP}/etc/suauth" ]; then
       ${CAT} > "${BKUP}/etc/suauth" << EOF
# /etc/suauth
# This is a Sample suauth file only
# You can modify and uncomment these lines for your own use

# Lines in this file are examined sequentially line by line and
# the first applicable line is used without examining further.

# Added by SAStk at "${CURRENT_DATE}"

# Examples

# Restrict su to root to the wheel group only
# root:ALL EXCEPT GROUP wheel:DENY

# Restrict su to root to user foo only
# root:ALL EXCEPT foo:deny

# Let users foo and foobar su to root using their own passwords
# root:foo,foobar:OWNPASS

# Let user foo su to root with no password
# root:foo:NOPASS

# Let user foo su to foobar using their foos own password
# foobar:foo:OWNPASS

EOF
        fi

${CAT} > "/etc/suauth" << EOF
# /etc/suauth

# Lines in this file are examined sequentially line by line and
# the first applicable line is used without examining further.

# Added by SAStk at "${CURRENT_DATE}"

# Restrict su to root to the wheel group only
root:ALL EXCEPT GROUP wheel:DENY 

# Examples

# Restrict su to root to user foo only
# root:ALL EXCEPT foo:deny

# Let users foo and foobar su to root using their own passwords
# root:foo,foobar:OWNPASS

# Let user foo su to root with no password
# root:foo:NOPASS

# Let user foo su to foobar using their foos own password
# foobar:foo:OWNPASS

EOF

${ECHO} "Restricting su to root to wheel group only" >> ${logfile}
   while [ ! "${some_answer}" = "NO" ]; do
${CLEAR}
${CAT} << EOF
********************************************************************************

Would you now like to add a user to the wheel group?

These users will be allowed to su to root

You may add users maunually with the command
    usermod -G wheel username

answer YES to add a user to the wheel group
answer NO  to move to the next question







********************************************************************************
EOF

check_answer "to if you want to add a user to the wheel group"
    if [ ! "${some_answer}" = "NO" ]; then
        ${ECHO} -ne "Please enter a valid user name: .\b"
        read user
            if [ -n "$(${EGREP} '[1-9][0-9][0-9][0-9]' /etc/passwd |${GREP} ^${user}\:)" ]; then
            ${USERMOD} -G wheel "${user}" 2>> ${errlog}
            ${ECHO} "${user} added to wheel group" 1>> ${logfile}
        else
            ${ECHO} "${user} is not a valid user!!"
            sleep 2
            fi   
    fi
done
fi
fi

${CLEAR}

###################
# Disable Daemons #
###################

# 
# We should disable the daemons, reboot and then install packages.
# It should be more secure this way, since there could be stray daemons
# running spawned by one of the processes we wish to disable.
#
# If we write to a status file, then on reboot the script can resume where
# it left off.
#

${ECHO} "Disabling daemons"

# Set the first argument to a more meaningful variable and see if it's
# writable.  Normally the argument will be /etc/rc.d/rc.conf.  We could ask the
# user if they want to name the file, but it will almost always be
# /etc/rc.d/rc.conf
FILE="/etc/rc.d/rc.conf"
if [ -w ${FILE} ]; then

# Display a message to the user about what this is. 
VARIABLE=begin
display_info_daemon ${VARIABLE};
read junk    # We don't care what this value is, just make it so they have to
# read the intro
${CLEAR}
${ECHO} "This line will be used for status on the last choice from this point on"
${ECHO} -e "********************************************************************************\n"
# Go through the file searching for any _enable= variables since these all
# correspond to services.
for RCCONF in $(${GREP} '^ *[A-Za-z0-9_]*_enable=' ${FILE} | ${AWK} 'BEGIN { FS = "=[ \t] *|[ \t]+"} {print $1 $2}' | ${CUT} -f1 -d'#')
    do
        VARIABLE=$(${ECHO} ${RCCONF} | ${CUT} -f1 -d=)
        VALUE=$(${ECHO} ${RCCONF} | ${CUT} -f2 -d=)
	display_info_daemon ${VARIABLE}
        ${ECHO} -e "\nDo you want to enable ${VARIABLE} ?"
        ${ECHO} "Currently, your configuration has it as ${VALUE}"
        ${ECHO} -e "********************************************************************************"
        ${ECHO} -n "answer: "
        read answer
	answer=$(${ECHO} ${answer} | ${TR} "[:lower:]" "[:upper:]")
        until [ X"${answer}" = X"NO" -o X"${answer}" = X"YES" ]; do
		if [ X"${answer}" = X ]; then
		    answer="${VALUE}"
		    break
		fi
            ${ECHO} "You entered an incorrect response, please choose YES or NO."
            read answer
	    answer=$(${ECHO} ${answer} | ${TR} "[:lower:]" "[:upper:]")
        done 
        if [ X"${answer}" = X"YES" ]; then
            if [ X"${VALUE}" = X"NO" ]; then
                ${SED} -e "s/${RCCONF}/${VARIABLE}=YES/" ${FILE} > ${FILE}.old;
                ${MV} ${FILE}.old ${FILE}
                VAR_NAME=$(${ECHO} "${VARIABLE}" | ${AWK} -F '_enable' '{print $1}' )
                ${ECHO} "Enabling ${VAR_NAME}" >> ${logfile}
                ${CLEAR}
                ${ECHO} "${RCCONF} has been changed to ${VARIABLE}=${answer}"
                ${ECHO} -e "********************************************************************************\n"
             else
                ${CLEAR}
                ${ECHO} "${RCCONF} has not been altered"
                ${ECHO} -e "********************************************************************************\n"
             fi 
          # Because of the above until statement, we can assume this is "NO"
          else
              if [ X"${VALUE}" = X"YES" ]; then 
                 ${SED} -e "s/${RCCONF}/${VARIABLE}=NO/" ${FILE} > ${FILE}.old;
                 ${MV} ${FILE}.old ${FILE}
                 VAR_NAME=$(${ECHO} "${VARIABLE}" | ${AWK} -F '_enable' '{print $1}' )
                 ${ECHO} "Disabling ${VAR_NAME}" >> ${logfile}
                 ${CLEAR}
                 ${ECHO} "${RCCONF} has been changed to ${VARIABLE}=${answer}"
                 ${ECHO} -e "********************************************************************************\n"
             else
                ${CLEAR}
                ${ECHO} "${RCCONF} has not been altered"
                ${ECHO} -e "********************************************************************************\n"
            fi
        fi
    done
fi

##########################
# Done disabling daemons #
##########################

# Configure the network
${CLEAR}
${CAT} << EOF
     Configuring the network
********************************************************************************

Time to set up your network.


If you have just installed SAStk then you will need to say YES here.

Answering YES here will start up 'netconfig' to configure your network settings.

If you answer NO and wish to set up your network at a later date you can run 
 'netconfig' or edit the network settings in the /etc/rc.d/rc.conf file by hand


If you wish to configure your network then say YES to this question.
                                                                             
                              







********************************************************************************
EOF
check_answer "to answer if you want to configure your network"
# Run netconfig
if [ ! "${some_answer}" = "NO" ]; then
. ${NETCONFIG}
fi

############
# Clean up #
############

${CLEAR}
${ECHO} "Cleaning up temporary files"
${RM} -rf "${TMPDIR}"

# unset anything we've exported
for i in errlog logfile BKUP LOG RC SENDMAILDIR TMPDIR version ; do
    unset $i
done

# Take care of .bash_login
if [ -f /root/.bash_login.bak ]; then
    ${MV} /root/.bash_login.bak /root/.bash_login
elif [ -f /root/.bash_login ]; then
    ${RM} "/root/.bash_login"
fi

export PATH="${OLDPATH}"

${ECHO} "Slackware Administrator's Security Toolkit has completed successfully"
${ECHO} "${SASTK_ID}"
${ECHO} -e "This session started at ${CURRENT_DATE}\n"
${ECHO} ""

if [ "$(${RUNLEVEL} | ${AWK} '{print $2}')" = "1" ]; then
    ${ECHO} ""
    ${CLEAR}
    quit=n
    ${CAT} << EOF

While it is unlikely, there is the possibility that some services/deamons 
may still be running.
A telinit 3 will return you to Multi-user mode but we would highly recommend
rebooting the system to be sure all services/daemons are stopped and 
or restarted with your new configuration.

EOF
    while [ "${quit}" = "n" ]; do
        ${CAT} << EOF

Choose an option from the list

1) Reboot the system 
2) Halt the system 
3) Enter Multi user mode
Q) Quit this script and stay in single user mode

EOF

      ${ECHO} -ne "Choose an option: .\b"
      read choice
      case ${choice} in

          1)       ${SHUTDOWN} -r now;
                   ${CLEAR};exit 0
                   ;;
          2)       ${SHUTDOWN} -h now;
                   ${CLEAR};exit 0
                   ;;
          3)       ${ECHO} "Switching to Multi user Mode."
                   ${TELINIT} 3; exit 0
                   ;;
        Q|q)       ${CLEAR};quit="y" 
                   ;;
          *)       ${ECHO} -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi


#################
# End of script #
#################
